@@ -1,3 +1,19 @@
+test_that("file_cache with cache=NULL", {
+  expected_dir <- here::here("cache")
+  dir_already_exists <- fs::dir_exists(expected_dir)
+
+  .cache <- file_cache()
+  expect_equal(
+    fs::path_abs(.cache$info()$dir),
+    fs::path_abs(expected_dir)
+  )
+
+  if (!dir_already_exists) {
+    expect_true(fs::dir_exists(expected_dir))
+    .cache$destroy()
+  }
+})
+
 test_that("file_cache with type=NULL works", {
   tf <- tempfile()
   dir.create(tf)
@@ -8,7 +24,7 @@ test_that("file_cache with type=NULL works", {
   cache$set("test", 3)
   expect_true(fs::is_file(fs::path(tf, "test.cache_rds")))
 
-  unlink(tf)
+  unlink(tf, recursive = TRUE)
 })
 
 test_that("file_cache with type=rds works", {
@@ -21,7 +37,7 @@ test_that("file_cache with type=rds works", {
   cache$set("test", 3)
   expect_true(fs::is_file(fs::path(tf, "test.cache_rds")))
 
-  unlink(tf)
+  unlink(tf, recursive = TRUE)
 })
 
 test_that("file_cache with type=parquet works", {
@@ -34,7 +50,7 @@ test_that("file_cache with type=parquet works", {
   cache$set("test", data.frame(x = 1:3))
   expect_true(fs::is_file(fs::path(tf, "test.cache_parquet")))
 
-  unlink(tf)
+  unlink(tf, recursive = TRUE)
 })
 
 test_that("file_cache with type=csv, ext_prefix=NULL works", {
@@ -47,12 +63,13 @@ test_that("file_cache with type=csv, ext_prefix=NULL works", {
   cache$set("test", data.frame(x = 1:3))
   expect_true(fs::is_file(fs::path(tf, "test.csv")))
 
-  unlink(tf)
+  unlink(tf, recursive = TRUE)
 })
 
-test_that("file_cache with cache_mem does not error", {
-  expect_no_error({
-    mem_cache <- file_cache(cache = cachem::cache_mem())
-  })
-  expect_true(inherits(mem_cache, "cache_mem"))
+test_that("file_cache passes existing cache object", {
+  cd <- cachem::cache_disk()
+  expect_identical(file_cache(cd), cd)
+
+  cm <- cachem::cache_mem()
+  expect_identical(file_cache(cm), cm)
 })
